Documentation
¶
Index ¶
Constants ¶
const ( MonitoringAPIVersion = "monitoring.coreos.com/v1" CalicoNodeAlertmanager = "calico-node-alertmanager" CalicoNodeMonitor = "calico-node-monitor" CalicoNodePrometheus = "calico-node-prometheus" CalicoPrometheusOperator = "calico-prometheus-operator" CalicoPrometheusOperatorSecret = "calico-prometheus-operator-secret" TigeraPrometheusObjectName = "tigera-prometheus" TigeraPrometheusRule = "calico" TigeraPrometheusRole = "tigera-prometheus-role" TigeraPrometheusRoleBinding = "tigera-prometheus-role-binding" // TigeraExternalPrometheus is the name of the objects created when Monitor.Spec.ExternalPrometheus is enabled. TigeraExternalPrometheus = "tigera-external-prometheus" PrometheusAPIPolicyName = networkpolicy.CalicoComponentPolicyPrefix + "tigera-prometheus-api" PrometheusClientTLSSecretName = "calico-node-prometheus-client-tls" PrometheusClusterRoleName = "prometheus" PrometheusDefaultPort = 9090 PrometheusServiceServiceName = "prometheus-http-api" PrometheusOperatorPolicyName = networkpolicy.CalicoComponentPolicyPrefix + "prometheus-operator" PrometheusPolicyName = networkpolicy.CalicoComponentPolicyPrefix + "prometheus" PrometheusProxyPort = 9095 PrometheusServiceAccountName = "prometheus" PrometheusServerTLSSecretName = "calico-node-prometheus-tls" AlertmanagerPolicyName = networkpolicy.CalicoComponentPolicyPrefix + CalicoNodeAlertmanager AlertmanagerConfigSecret = "alertmanager-calico-node-alertmanager" AlertmanagerPort = 9093 MeshAlertmanagerPolicyName = AlertmanagerPolicyName + "-mesh" ElasticsearchMetrics = "elasticsearch-metrics" FluentdMetrics = "fluentd-metrics" KubeControllerMetrics = "calico-kube-controllers-metrics" // OperatorTLSSecretName is the TLS keypair for the operator. Currently used for the metrics // endpoint mTLS, but not metrics-specific so it can serve other operator TLS needs in the future. OperatorTLSSecretName = "tigera-operator-tls" OperatorMetricsServiceName = "tigera-operator-metrics" OperatorMetricsPortName = "tigera-operator-metrics-port" OperatorMetricsPort = 9484 )
Variables ¶
This section is empty.
Functions ¶
func MonitorPolicy ¶ added in v1.28.0
Types ¶
type Config ¶ added in v1.25.0
type Config struct {
Monitor operatorv1.MonitorSpec
Installation *operatorv1.InstallationSpec
PullSecrets []*corev1.Secret
AlertmanagerConfigSecret *corev1.Secret
KeyValidatorConfig authentication.KeyValidatorConfig
ServerTLSSecret certificatemanagement.KeyPairInterface
ClientTLSSecret certificatemanagement.KeyPairInterface
ClusterDomain string
TrustedCertBundle certificatemanagement.TrustedBundle
OpenShift bool
KubeControllerPort int
FelixPrometheusMetricsEnabled bool
LicenseExpired bool
// Operator metrics fields.
OperatorMetricsEnabled bool
OperatorNamespace string
OperatorName string
OperatorTLSSecret certificatemanagement.KeyPairInterface
}
Config contains all the config information needed to render the Monitor component.
Click to show internal directories.
Click to hide internal directories.